/*****************************************************************************
* FILENAME
*   Sweep.c
*
* DESCRIPTION
*   Sweep sinewave generation using IIR filters for the TMS320C6711 DSK 
*
*  Rev 1.00   R.Sikora
*
*-----------------------------------------------------------------------------
*  HISTORY
*  Rev 1.00  16 December 2001. Created by R.Sikora. 
*     
*
******************************************************************************/

#include <stdio.h>
#include <c6x.h>
#include "c6211dsk.h"
#include "sine_IIR.h"
#include "sweep_table.h"
#include "timers.h"


/*-------------------------------------------------------------------------*/
/* sweep_frequencies()                                                     */
/*-------------------------------------------------------------------------*/
/*                                                                         */
/* Uses IIR sine wave generation to perform a frequency sweep from 20 Hz   */
/* to 10 kHz. The frequencies change 20 times per second under the control */
/* of timer0_flag in timers.c                                              */
/*                                                                         */
/*-------------------------------------------------------------------------*/

int sweep_frequencies(void)
{
 int output;
 static int sweep_index = 0;   /* Retain values between calls */
 static int last_output;       /* Last output */

 output = sinewave( sweep_values[sweep_index][0], sweep_values[sweep_index][1]); 
  
 if ( timer0_flag)
  {
   /* Timer 0 interrupt has occurred */
   
   if( last_output <= 0 && output >= 0)
    {
     /* Output has now crossed zero going positive */
    
     timer0_flag = 0; /* Reset timer 0 flag */
   
     if ( sweep_index < SWEEP_MAX_INDEX)
      {
       sweep_index ++; /* Next frequency to sweep */ 
      }
     else
      {
       sweep_index = 0; /* Go back to beginning of sweep */
      }  
      
     sinewave_initialize();   /* Start at beginning of sine wave */
     output = sinewave( sweep_values[sweep_index][0], sweep_values[sweep_index][1]); 
    }  
  }
       
 last_output = output; /* Remember output for next time*/

 return(output);
}

  /*-----------------------------------------------------------------------*/
  /* End of sweep.c                                                        */
  /*-----------------------------------------------------------------------*/
  









